#[non_exhaustive]pub struct PostureDeployment {Show 14 fields
pub name: String,
pub target_resource: String,
pub state: State,
pub posture_id: String,
pub posture_revision_id: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub etag: String,
pub annotations: HashMap<String, String>,
pub reconciling: bool,
pub desired_posture_id: String,
pub desired_posture_revision_id: String,
pub failure_message: String,
/* private fields */
}Expand description
========================== PostureDeployments ========================== Message describing PostureDeployment resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of this PostureDeployment resource, in the format of organizations/{organization}/locations/{location_id}/postureDeployments/{postureDeployment}.
target_resource: StringRequired. Target resource where the Posture will be deployed. Currently supported resources are of types: projects/projectNumber, folders/folderNumber, organizations/organizationNumber.
state: StateOutput only. State of PostureDeployment resource.
posture_id: StringRequired. Posture that needs to be deployed. Format: organizations/{org_id}/locations/{location_id}/postures/<posture> Example: organizations/99/locations/global/postures/les-miserables.
posture_revision_id: StringRequired. Revision_id of the Posture that is to be deployed.
create_time: Option<Timestamp>Output only. The timestamp that the PostureDeployment was created.
update_time: Option<Timestamp>Output only. The timestamp that the PostureDeployment was updated.
description: StringOptional. User provided description of the PostureDeployment.
etag: StringOptional. An opaque tag indicating the current version of the
PostureDeployment, used for concurrency control. When the
PostureDeployment is returned from either a GetPostureDeployment or a
ListPostureDeployments request, this etag indicates the version of the
current PostureDeployment to use when executing a read-modify-write loop.
When the PostureDeployment is used in a UpdatePostureDeployment method,
use the etag value that was returned from a GetPostureDeployment
request as part of a read-modify-write loop for concurrency control. Not
setting the etag in a UpdatePostureDeployment request will result in an
unconditional write of the PostureDeployment.
annotations: HashMap<String, String>Optional. User annotations. These attributes can only be set and used by the user, and not by Google Security Postures. .
reconciling: boolOutput only. Whether or not this Posture is in the process of being updated.
desired_posture_id: StringOutput only. This is a output only optional field which will be filled in case where PostureDeployment state is UPDATE_FAILED or CREATE_FAILED or DELETE_FAILED. It denotes the desired Posture.
desired_posture_revision_id: StringOutput only. Output only optional field which provides revision_id of the desired_posture_id.
failure_message: StringOutput only. This is a output only optional field which will be filled in case where PostureDeployment enters a failure state like UPDATE_FAILED or CREATE_FAILED or DELETE_FAILED.
Implementations
Sourceimpl PostureDeployment
impl PostureDeployment
Sourcepub fn set_target_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_target_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of target_resource.
Example
let x = PostureDeployment::new().set_target_resource("example");Sourcepub fn set_posture_id<T: Into<String>>(self, v: T) -> Self
pub fn set_posture_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_posture_revision_id<T: Into<String>>(self, v: T) -> Self
pub fn set_posture_revision_id<T: Into<String>>(self, v: T) -> Self
Sets the value of posture_revision_id.
Example
let x = PostureDeployment::new().set_posture_revision_id("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = PostureDeployment::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = PostureDeployment::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = PostureDeployment::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = PostureDeployment::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = PostureDeployment::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = PostureDeployment::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = PostureDeployment::new().set_description("example");Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = PostureDeployment::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_desired_posture_id<T: Into<String>>(self, v: T) -> Self
pub fn set_desired_posture_id<T: Into<String>>(self, v: T) -> Self
Sets the value of desired_posture_id.
Example
let x = PostureDeployment::new().set_desired_posture_id("example");Sourcepub fn set_desired_posture_revision_id<T: Into<String>>(self, v: T) -> Self
pub fn set_desired_posture_revision_id<T: Into<String>>(self, v: T) -> Self
Sets the value of desired_posture_revision_id.
Example
let x = PostureDeployment::new().set_desired_posture_revision_id("example");Sourcepub fn set_failure_message<T: Into<String>>(self, v: T) -> Self
pub fn set_failure_message<T: Into<String>>(self, v: T) -> Self
Sets the value of failure_message.
Example
let x = PostureDeployment::new().set_failure_message("example");Trait Implementations
Sourceimpl Clone for PostureDeployment
impl Clone for PostureDeployment
Sourcefn clone(&self) -> PostureDeployment
fn clone(&self) -> PostureDeployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PostureDeployment
impl Debug for PostureDeployment
Sourceimpl Default for PostureDeployment
impl Default for PostureDeployment
Sourcefn default() -> PostureDeployment
fn default() -> PostureDeployment
Sourceimpl Message for PostureDeployment
impl Message for PostureDeployment
Sourceimpl PartialEq for PostureDeployment
impl PartialEq for PostureDeployment
impl StructuralPartialEq for PostureDeployment